@@ -58,6 +58,8 @@ use MKDoc::Auth;
 use warnings;
 use strict;
 
+our $AUTOLOAD;
+
 our @ISA = ();
 
 
@@ -256,6 +258,26 @@ sub _cache_object
 }
 
 
+sub AUTOLOAD
+{
+    my ($pkg, $name) = $AUTOLOAD =~ /(.*)::(.*)/;
+
+    my $self  = shift;
+    my $super = $::MKD_Auth_User_CLASS || 'MKDoc::Auth::User';
+
+    local @ISA = ();
+    push  @ISA, $super;
+
+    my $code = eval "sub { $super" . "::$name (\@_) }";
+    return $code->($self, @_);
+}
+
+
+sub DESTROY
+{
+}
+
+
 1;
 
 
